@@ -1,11 +1,11 @@
 /* HiddenArea.m
  * Object for calculation of hidden areas
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2004 by vhf interservice GmbH
  * Author:   Ilonka Fleischmann
  *
  * created:  1996-09-24
- * modified: 2005-04-25 (clean up)
+ * modified: 2004-12-13
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -120,7 +120,7 @@
             c--;
         }
     }
-    [self uniteAreas:list];
+    return [self uniteAreas:list];
 }
 
 /* unite graphics in list which have the same color - remove other graphic
