@@ -1,11 +1,11 @@
 /* VGroup.m
  * Group of graphic objects
  *
- * Copyright (C) 1996-2010 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-29
- * modified: 2010-07-08 (relocated setList:)
+ * modified: 2005-01-07
  *
  * the group is implemented as follows:
  * - all objects are stored in a list with absolute coordinates
@@ -125,111 +125,26 @@
 
 - (NSString*)title		{ return @"Group"; }
 
-- (NSMutableArray*)list
+- list
 {
     return list;
 }
-- (void)setList:(NSArray*)aList
-{
-    [list release];
-    list = [aList retain];
-    [self setColorNew];
-    coordBounds = bounds = NSZeroRect;
-    dirty = YES;
-}
 
 - (unsigned)countRecursive
-{   int	i, cnt = 0;
+{   int	i, cnt = [list count];
 
     for (i=[list count]-1; i>=0; i--)
     {	id	g = [list objectAtIndex:i];
 
-        if ( [g isKindOfClass:[VGroup class]] ) // || [g isKindOfClass:[VPath class]] 
+        if ( [g isKindOfClass:[VGroup class]] || [g isKindOfClass:[VPath class]] )
             cnt += [g countRecursive];
-        else
-            cnt++;
     }
     return cnt;
 }
-/* created 2005-08-19
- */
-- (id)recursiveObjectAtIndex:(int)ix
-{   int	i, cnt = [list count], cCnt = 0;
 
-    for (i=0; i < cnt; i++)
-    {	id	g = [list objectAtIndex:i];
-
-        if ([g isKindOfClass:[VGroup class]])
-        { int	gCnt = [g countRecursive];
-
-            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
-                return [g recursiveObjectAtIndex:(ix-cCnt)];
-            cCnt += [g countRecursive];
-        }
-        else if (cCnt == ix)
-            return g;
-        else
-            cCnt++;
-    }
-    return nil;
-}
-- (void)recursiveRemoveObjectAtIndex:(int)ix
-{   int	i, cnt = [list count], cCnt = 0;
-
-    for (i=0; i < cnt; i++)
-    {	id	g = [list objectAtIndex:i];
-
-        if ([g isKindOfClass:[VGroup class]])
-        {   int	gCnt = [g countRecursive];
-
-            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
-            {   [g recursiveRemoveObjectAtIndex:(ix-cCnt)];
-                return;
-            }
-            cCnt += [g countRecursive];
-        }
-        else if (cCnt == ix)
-        {   [list removeObjectAtIndex:i];
-            return;
-        }
-        else
-            cCnt++;
-    }
-}
-- (void)recursiveInsertObject:(id)obj atIndex:(int)ix
-{   int	i, cnt = [list count], cCnt = 0;
-
-    if (ix >= [self countRecursive])
-    {
-        if ([[list objectAtIndex:cnt-1] isKindOfClass:[VGroup class]]) // last obj is a group
-            [[[list objectAtIndex:cnt-1] list] addObject:obj];
-        else
-            [list addObject:obj];
-    }
-
-    for (i=0; i < cnt; i++)
-    {	id	g = [list objectAtIndex:i];
-
-        if ([g isKindOfClass:[VGroup class]])
-        {   int	gCnt = [g countRecursive];
-
-            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
-            {   [g recursiveInsertObject:obj atIndex:(ix-cCnt)];
-                return;
-            }
-            cCnt += [g countRecursive];
-        }
-        else if (cCnt == ix)
-        {   [list insertObject:obj atIndex:i];
-            return;
-        }
-        else
-            cCnt++;
-    }
-}
-
-/* created:  1995-09-24
- * modified: 
+/* created:  24.09.95
+ * modified:
+ * purpose:
  */
 - (void)deselectAll
 {   int	i;
@@ -250,8 +165,6 @@
     NSPoint	rc0={0.5,0.5}, rc1={0.5,0.5};
 
     uniColoring = NO;
-    if (![list count])
-        return;
     gr0 = [list objectAtIndex:0];
     if ( [gr0 isKindOfClass:[VGroup class]] && [(VGroup*)gr0 uniColored] == NO )
         return;
@@ -295,7 +208,7 @@
 }
 
 - (void)setColorNew
-{   int		i, cnt, fild0 = 0, fild1 = 0;
+{   int		i, cnt, fild0=0, fild1=0;
     VGraphic	*gr0, *gr1;
     NSColor	*col0, *fcol0 = nil, *ecol0 = nil, *col1, *fcol1 = nil, *ecol1 = nil;
     float	w0 = 0, ga0 = 0, w1 = 0, ga1 = 0;
@@ -307,13 +220,11 @@
     width = 0.0;
     filled = NO;
     fillColor = [[NSColor blackColor] retain];
-    endColor  = [[NSColor blackColor] retain];
+    endColor = [[NSColor blackColor] retain];
     graduateAngle = 0.0;
     stepWidth = 7.0;
     radialCenter = NSMakePoint(0.5, 0.5);
 
-    if (![list count])	// empty group
-        return;
     gr0 = [list objectAtIndex:0];
     if ( [gr0 isKindOfClass:[VGroup class]] && [(VGroup*)gr0 uniColored] == NO )
         return;
@@ -510,12 +421,22 @@
 - (void)setSelected:(BOOL)flag
 {
     if (!flag)
-    {
-        if (selectedObject >= 0)
+    {	if (selectedObject >= 0)
             [[list objectAtIndex:selectedObject] setSelected:NO];
         selectedObject = -1;
     }
-    [super setSelected:flag];
+    return [super setSelected:flag];
+}
+
+/* returns the old list
+ */
+- (void)setList:(NSArray*)aList
+{
+    [list release];
+    list = [aList retain];
+    [self setColorNew];
+    coordBounds = bounds = NSZeroRect;
+    dirty = YES;
 }
 
 - (void)addObject:g
@@ -610,17 +531,19 @@
  * add a list to our list
  * after the operation we are selected, all of our objects are deselected
  */
-- (void)add:(NSArray*)addList
+- (void)add:addList
 {   int	i, cnt;
 
     if (!list)
         list = [[NSMutableArray allocWithZone:[self zone]] init];
+
     for (i=0, cnt=[addList count]; i<cnt; i++)
     {	id	g = [addList objectAtIndex:i];
 
         [g setSelected:NO];
         [list addObject:g];
     }
+
     [self setSelected:YES];
     coordBounds = bounds = NSZeroRect;
 }
@@ -719,8 +642,7 @@
         coordBounds = [[list objectAtIndex:cnt] coordBounds];
         for (i=cnt-1; i>=0; i--)
         {   rect = [[list objectAtIndex:i] coordBounds];
-            if ( rect.size.width > 0.0 && rect.size.height > 0.0 )    // in case we have a bogus object
-                coordBounds = VHFUnionRect(rect, coordBounds);
+            coordBounds = VHFUnionRect(rect, coordBounds);
         }
     }
     return coordBounds;
@@ -793,8 +715,8 @@
                 //[obj drawKnobs:rect direct:direct scaleFactor:scaleFactor];
                 [obj drawControls:rect direct:direct scaleFactor:scaleFactor];
                 [obj setSelected:sel];
-                /*if ([obj isMemberOfClass:[VCurve class]])
-                {   [NSBezierPath setDefaultLineWidth:1.0/scaleFactor];
+/*                if ([obj isMemberOfClass:[VCurve class]])
+                {   [NSBezierPath setDefaultLineWidth:0.0];
                     [NSBezierPath strokeLineFromPoint:[obj pointWithNum:0] toPoint:[obj pointWithNum:1]];
                     [NSBezierPath strokeLineFromPoint:[obj pointWithNum:3] toPoint:[obj pointWithNum:2]];
                 }*/
@@ -1063,15 +985,6 @@
     dirty = YES;
 }
 
-- (void)transform:(NSAffineTransform*)matrix
-{   int	i;
-
-    for ( i=[list count]-1; i >= 0; i-- )
-        [[list objectAtIndex:i] transform:matrix];
-    coordBounds = bounds = NSZeroRect;
-    dirty = YES;
-}
-
 - (void)scale:(float)x :(float)y withCenter:(NSPoint)cp
 {   int		i;
 
@@ -1206,7 +1119,6 @@
     return group;
 }
 
-#if 0
 - getListOfObjectsSplittedFrom:(NSPoint*)pArray :(int)iCnt
 {   NSMutableArray	*splitList = [NSMutableArray array], *spList = nil;
     int			i, j, cnt = [list count];
@@ -1231,10 +1143,10 @@
 }
 
 - (int)getIntersections:(NSPoint**)ppArray with:g
-{   int		i, j, iCnt = 0, ptsCnt = Min(100, [self numPoints]);
+{   int		i, j, iCnt = 0;
     NSPoint	*pts;
 
-    *ppArray = malloc(ptsCnt * sizeof(NSPoint));
+    *ppArray = malloc(([list count]*9) * sizeof(NSPoint));
     for (i=[list count]-1; i>=0; i--)
     {	id	gp = [list objectAtIndex:i];
         int	cnt, oldCnt = iCnt;
@@ -1243,9 +1155,6 @@
             continue;
 
         cnt = [gp getIntersections:&pts with:g];	/* line, arc, curve */
-        if (iCnt+cnt >= ptsCnt)
-            *ppArray = realloc(*ppArray, (ptsCnt+=cnt*2) * sizeof(NSPoint));
-
         for (j=0; j<cnt; j++)
         {
             if ( !pointInArray(pts[j], *ppArray, oldCnt) )
@@ -1304,7 +1213,6 @@
 
     return iCnt;
 }
-#endif
 
 - (float)sqrDistanceGraphic:g
 {   int		i;
@@ -1387,15 +1295,15 @@
 
     return newGroup;
 }*/
-#if 0
+
 - getIntersectionsAndSplittedObjects:(NSPoint**)ppArray :(int*)iCnt with:g
-{   int			i, j, lCnt = [list count], ptsCnt = Min(100, [self numPoints]);
+{   int			i, j, lCnt = [list count];
     NSPoint		*pts;
     NSRect		gBounds = [g bounds];
     NSMutableArray	*splitList = [NSMutableArray array], *spList = nil;
 
     *iCnt = 0;
-    *ppArray = malloc(ptsCnt * sizeof(NSPoint));
+    *ppArray = malloc(([list count]*9) * sizeof(NSPoint));
 //    for (i=[list count]-1; i>=0; i--)
     for (i=0; i<lCnt; i++)
     {	id	gp = [list objectAtIndex:i];
@@ -1423,10 +1331,6 @@
             else
                 [splitList addObject:[[gp copy] autorelease]];
         }
-
-        if ((*iCnt)+cnt >= ptsCnt)
-            *ppArray = realloc(*ppArray, (ptsCnt+=cnt*2) * sizeof(NSPoint));
-
         for (j=0; j<cnt; j++)
         {
             if ( !pointInArray(pts[j], *ppArray, oldCnt) )
@@ -1574,7 +1478,6 @@
     [pool release];
     return ng;
 }
-#endif
 
 - (void)writeFilesToDirectory:(NSString*)directory
 {   int	i;
