@@ -1,13 +1,11 @@
 /* VRectangle.m
  * 2-D Rectangle object
  *
- * Copyright (C) 1996-2010 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-09-17
- * modified: 2010-07-17 (-transform added, -scale: scales width correctly with negative scales (flip))
- *           2010-03-03 (-copy setDirectionCCW, -pathRepresentation edges build with r, not radius)
- *           2006-02-08
+ * modified: 2005-01-11
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -71,7 +69,7 @@
 {
     [self setParameter];
     fillColor = [[NSColor blackColor] retain];
-    endColor  = [[NSColor blackColor] retain];
+    endColor = [[NSColor blackColor] retain];
     graduateAngle = 0.0;
     stepWidth = 7.0;
     radialCenter = NSMakePoint(0.5, 0.5);
@@ -90,7 +88,7 @@
 {   id		rectangle = [[VRectangle allocWithZone:[self zone]] init];
 
     [rectangle setSelected:isSelected];
-    [rectangle setLocked:NO];
+    [rectangle setLocked:isLocked];
     [rectangle setFilled:filled];
     [rectangle setWidth:width];
     [rectangle setColor:color];
@@ -134,7 +132,7 @@
 #define CREATEEVENTMASK NSLeftMouseDraggedMask|NSLeftMouseDownMask|NSLeftMouseUpMask|NSPeriodicMask
 - (BOOL)create:(NSEvent *)event in:(DocView*)view
 {   NSRect	viewBounds, gridBounds, drawBounds;
-    NSPoint	start, last, gridPoint, drawPoint, rSize, p, lastPoint = NSZeroPoint, hitPoint;
+    NSPoint	start, last, gridPoint, drawPoint, rSize, p, lastPoint, hitPoint;
     id		window = [view window];
     VRectangle 	*drawRectangleGraphic;
     BOOL	ok = YES, dragging = NO, hitEdge = NO, inTimerLoop = NO;
@@ -345,8 +343,6 @@
 
 /* return a path representation of the arc
  * returns an autoreleased object
- * modified: 2010-03-03 (edges build with r, not radius)
- *           2005-11-22 (max radius = 1/2 size, skip zero lines)
  */
 - (VPath*)pathRepresentation
 {   VPath		*pathG = [VPath path];
@@ -364,7 +360,7 @@
     pts[2].x = origin.x + size.x; pts[2].y = origin.y + size.y;
     pts[3].x = origin.x; pts[3].y = origin.y + size.y;
     if (size.x < r*2.0 || size.y < r*2.0)
-        r = Min(size.x, size.y) / 2.0;
+        r = 0.0;
 
     for ( i=(ccw)?0:4; (ccw)?i<4:i; (ccw)?i++:i-- )
     {
@@ -373,16 +369,15 @@
         p0.y = pts[i].y + ((pts[i].y<pts[j].y) ? r : ((pts[i].y>pts[j].y) ? -r : 0));
         p1.x = pts[j].x + ((pts[i].x<pts[j].x) ? -r : ((pts[i].x>pts[j].x) ? r : 0));
         p1.y = pts[j].y + ((pts[i].y<pts[j].y) ? -r : ((pts[i].y>pts[j].y) ? r : 0));
-        if ( r == 0.0 || p0.x != p1.x || p0.y != p1.y )
-        {   line = [VLine line];
-            [line setVertices:p0 :p1];
-            [line setColor:color];
-            [[pathG list] addObject:line];
-        }
+        line = [VLine line];
+        [line setVertices:p0 :p1];
+        [line setColor:color];
+        [[pathG list] addObject:line];
+
         if ( r )
         {
-            c.x = pts[j].x + ((pts[j].x>pts[0].x) ? -r : r);
-            c.y = pts[j].y + ((pts[j].y>pts[0].y) ? -r : r);
+            c.x = pts[j].x + ((pts[j].x>pts[0].x) ? -radius : radius);
+            c.y = pts[j].y + ((pts[j].y>pts[0].y) ? -radius : radius);
             arc = [VArc arc];
             [arc setCenter:c start:p1 angle:a];
             [arc setColor:color];
@@ -520,41 +515,20 @@
 {
     if (!flag)
         selectedKnob = -1;
-    [super setSelected:flag];
-}
-
-- (void)transform:(NSAffineTransform*)matrix
-{   NSSize  s = NSMakeSize(width, width);
-
-    s = [matrix transformSize:s];
-    width = (Abs(s.width) + Abs(s.height)) / 2;
-    origin = [matrix transformPoint:origin];
-    size   = [matrix transformPoint:size];
-    if (size.x < 0.0)
-    {   origin.x += size.x;
-        size.x = -size.x;
-    }
-    if (size.y < 0.0)
-    {   origin.y += size.y;
-        size.y = -size.y;
-    }
-    dirty = graduateDirty = YES;
+    return [super setSelected:flag];
 }
 
 - (void)scale:(float)x :(float)y withCenter:(NSPoint)cp
 {
-    width *= (Abs(x)+Abs(y))/2.0;
+    width *= (x+y)/2.0;
     origin.x = ScaleValue(origin.x, cp.x, x);
-    if ( x < 0.0)
-        origin.x += size.x * x;
     origin.y = ScaleValue(origin.y, cp.y, y);
-    if ( y < 0.0)
-        origin.y += size.y * y;
-    size.x *= Abs(x);
-    size.y *= Abs(y);
+    size.x *= x;
+    size.y *= y;
     coordBounds = NSZeroRect;
 
-    dirty = graduateDirty = YES;
+    dirty = YES;
+    graduateDirty = YES;
 }
 
 - (void)mirrorAround:(NSPoint)p
@@ -603,11 +577,6 @@
         if (graduateAngle > 360.0)
             graduateAngle -= 360.0;
         vhfRotatePointAroundCenter(&radialCenter, NSMakePoint(0.5, 0.5), -angle);
-        if (radialCenter.x > 1.0) radialCenter.x = 1.0;
-        if (radialCenter.x < 0.0) radialCenter.x = 0.0;
-        if (radialCenter.y > 1.0) radialCenter.y = 1.0;
-        if (radialCenter.y < 0.0) radialCenter.y = 0.0;
-        graduateDirty = YES;
     }
     vhfRotatePointAroundCenter(&origin, cp, -angle);
     rotAngle -= angle;
@@ -632,7 +601,8 @@
 {
     if ( !radius && !rotAngle && filled < 2 )
     {
-        [NSBezierPath setDefaultLineCapStyle: NSRoundLineCapStyle];
+        [NSBezierPath setDefaultLineWidth:width];
+        [NSBezierPath setDefaultLineCapStyle:NSRoundLineCapStyle];
         [NSBezierPath setDefaultLineJoinStyle:NSRoundLineJoinStyle];
 
         if ( filled )
@@ -657,12 +627,8 @@
 
             [NSBezierPath fillRect:NSMakeRect(origin.x, origin.y, size.x, size.y)];
         }
-        if ( width > 0.0 || !filled || Diff(size.x, 0) < 500*TOLERANCE || Diff(size.y, 0) < 500*TOLERANCE )
+        if ( width > 0.0 || !filled )
         {   NSColor	*oldColor=nil;
-            float	defaultWidth = [NSBezierPath defaultLineWidth];
-
-            if ( filled && (Diff(size.x, 0) < 500*TOLERANCE || Diff(size.y, 0) < 500*TOLERANCE) )
-                defaultWidth = 0.1 / [principal scaleFactor];   // make visible what actually is invisible
 
             if (!VHFIsDrawingToScreen() && [principal separationColor])
             {   NSColor	*sepColor = [self separationColor:color]; // get individual separation color
@@ -671,9 +637,7 @@
                 [self setColor:sepColor];
             }
             [super drawWithPrincipal:principal];	// set color
-            [NSBezierPath setDefaultLineWidth:(width > 0.0) ? width : defaultWidth];
-            [NSBezierPath strokeRect:NSMakeRect(origin.x, origin.y, Max( 0.01, size.x), Max( 0.01, size.y))];
-            [NSBezierPath setDefaultLineWidth:defaultWidth];
+            [NSBezierPath strokeRect:NSMakeRect(origin.x, origin.y, Max( 1.0, size.x), Max( 1.0, size.y))];
 
             if (!VHFIsDrawingToScreen() && [principal separationColor])
             {   [self setColor:oldColor];
@@ -682,9 +646,7 @@
         }
     }
     else if (filled <= 1)
-    {   [[self pathRepresentation] drawWithPrincipal:principal];
-        return;
-    }
+        return [[self pathRepresentation] drawWithPrincipal:principal];
     else // filled is 2 or 3 or 4
     {   VPath	*pathRep = [self pathRepresentation];
 
@@ -702,14 +664,13 @@
             graduateDirty = NO;
         }
         else if (graduateList && !graduateDirty)
-        {   int		i, gCnt = [graduateList count];
-            BOOL	antialias = VHFAntialiasing();
+        {   int	i, gCnt = [graduateList count];
 
             /* draw graduateList */
             VHFSetAntialiasing(NO);
             for (i=0; i<gCnt; i++)
                 [(VGraphic*)[graduateList objectAtIndex:i] drawWithPrincipal:principal];
-            if (antialias) VHFSetAntialiasing(antialias);
+            VHFSetAntialiasing(YES);
         }
         else
             NSLog(@"VRectangle: -drawWithPrincipal filling confusion\n");
@@ -804,52 +765,25 @@
     return bRect;
 }
 
-/* modified: 2005-10-18 (rounded corners added)
+/* FIXME: this should flatten the rectangle if it has round corners
  */
 - (NSPoint)appendToBezierPath:(NSBezierPath*)bPath currentPoint:(NSPoint)currentPoint
-{   int		i, j;
-    BOOL	ccw = [self isDirectionCCW];
-    NSPoint	p0, p1, c, pts[5];
-    float	a = (ccw) ? 90.0 : -90.0, r = radius, begAngle;
+{   NSPoint	p;
 
-    pts[0] = pts[4] = origin;
-    pts[1].x = origin.x + size.x; pts[1].y = origin.y;
-    pts[2].x = origin.x + size.x; pts[2].y = origin.y + size.y;
-    pts[3].x = origin.x; pts[3].y = origin.y + size.y;
-    if (size.x < r*2.0 || size.y < r*2.0)
-        r = 0.0;
-
-    for ( i=(ccw)?0:4; (ccw)?i<4:i; (ccw)?i++:i-- )
-    {
-        j = (ccw) ? i+1 : i-1;
-        p0.x = pts[i].x + ((pts[i].x<pts[j].x) ? r : ((pts[i].x>pts[j].x) ? -r : 0));
-        p0.y = pts[i].y + ((pts[i].y<pts[j].y) ? r : ((pts[i].y>pts[j].y) ? -r : 0));
-        p1.x = pts[j].x + ((pts[i].x<pts[j].x) ? -r : ((pts[i].x>pts[j].x) ? r : 0));
-        p1.y = pts[j].y + ((pts[i].y<pts[j].y) ? -r : ((pts[i].y>pts[j].y) ? r : 0));
-
-        if (rotAngle != 0.0)
-            p0 = vhfPointRotatedAroundCenter(p0, rotAngle, origin);
-
-        if ( (!i || i == 4) && (Diff(currentPoint.x, p0.x) > 0.01 || Diff(currentPoint.y, p0.y) > 0.01) )
-            [bPath moveToPoint:p0];
-
-        if (rotAngle != 0.0)
-            p1 = vhfPointRotatedAroundCenter(p1, rotAngle, origin);
-        [bPath lineToPoint:p1];
-
-        if ( r )
-        {
-            c.x = pts[j].x + ((pts[j].x>pts[0].x) ? -radius : radius);
-            c.y = pts[j].y + ((pts[j].y>pts[0].y) ? -radius : radius);
-            if (rotAngle != 0.0)
-                c = vhfPointRotatedAroundCenter(c, rotAngle, origin);
-
-            begAngle = vhfAngleOfPointRelativeCenter(p1, c);
-
-            [bPath appendBezierPathWithArcWithCenter:c radius:radius
-                                          startAngle:begAngle endAngle:begAngle+a clockwise:(a < 0.0)];
-        }
-    }
+    if (Diff(currentPoint.x, origin.x) > 0.01 || Diff(currentPoint.y, origin.y) > 0.01)
+        [bPath moveToPoint:origin];
+    p = NSMakePoint(origin.x + size.x, origin.y);
+    if (rotAngle != 0.0)
+	p = vhfPointRotatedAroundCenter(p, rotAngle, origin);
+    [bPath lineToPoint:p];
+    p = NSMakePoint(origin.x + size.x, origin.y + size.y);
+    if (rotAngle != 0.0)
+    	p = vhfPointRotatedAroundCenter(p, rotAngle, origin);
+    [bPath lineToPoint:p];
+    p = NSMakePoint(origin.x, origin.y + size.y);
+    if (rotAngle != 0.0)
+    	p = vhfPointRotatedAroundCenter(p, rotAngle, origin);
+    [bPath lineToPoint:p];
 
     return NSMakePoint(LARGENEG_COORD, LARGENEG_COORD);
 }
@@ -1011,11 +945,11 @@
 
     switch (pt_num)
     {
-        default:    // 2008-02-13 default changed from UL to LL
         case PT_LL:	p = origin; break;
         case PT_UL:	p.x = origin.x; p.y = origin.y + size.y; break;
         case PT_LR:	p.x = origin.x + size.x; p.y = origin.y; break;
-        case PT_UR:	p.x = origin.x + size.x; p.y = origin.y + size.y; break;
+        default:
+        case PT_UR:	p.x = origin.x + size.x; p.y = origin.y + size.y;
     }
     if (rotAngle)
         vhfRotatePointAroundCenter(&p, origin, rotAngle);
@@ -1044,8 +978,9 @@
         [self getPoint:i :&p];
         knobRect.origin.x = p.x - controlsize/2.0;
         knobRect.origin.y = p.y - controlsize/2.0;
-        if (selectedKnob != i && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p;
+            selectedKnob = i;
             return YES;
         }
     }
@@ -1084,66 +1019,28 @@
         vhfRotatePointAroundCenter(&p, origin, -rotAngle);
     bRect.origin.x = origin.x - fuzz;
     bRect.origin.y = origin.y - fuzz;
-    bRect.size.width  = size.x + 2.0*fuzz;
+    bRect.size.width = size.x + 2.0*fuzz;
     bRect.size.height = size.y + 2.0*fuzz;
     if ( NSPointInRect(p, bRect) )
-    {   int     i, j;
-        BOOL    ccw = [self isDirectionCCW];
-        NSPoint p0, p1, c, pts[5];
-        float   a = (ccw) ? 90.0 : -90.0, r = radius;
-        float   begAngles[4] = {270.0, 0.0, 90.0, 180.0};
+    {   NSPoint p0, p1, p2, p3;
 
-        pts[0] = pts[4] = origin;
-        pts[1].x = origin.x + size.x; pts[1].y = origin.y;
-        pts[2].x = origin.x + size.x; pts[2].y = origin.y + size.y;
-        pts[3].x = origin.x; pts[3].y = origin.y + size.y;
-        if (size.x < r*2.0 || size.y < r*2.0)
-            r = 0.0;
-
-        if ( !Prefs_SelectByBorder && filled && !r )
+        if ( filled )
             return YES;
-        if ( !Prefs_SelectByBorder && filled && r )
-            return [[self pathRepresentation] hit:p fuzz:fuzz];
 
-        for ( i=(ccw)?0:4; (ccw)?i<4:i; (ccw)?i++:i-- )
-        {
-            j = (ccw) ? i+1 : i-1;
-            p0.x = pts[i].x + ((pts[i].x<pts[j].x) ? r : ((pts[i].x>pts[j].x) ? -r : 0));
-            p0.y = pts[i].y + ((pts[i].y<pts[j].y) ? r : ((pts[i].y>pts[j].y) ? -r : 0));
-            p1.x = pts[j].x + ((pts[i].x<pts[j].x) ? -r : ((pts[i].x>pts[j].x) ? r : 0));
-            p1.y = pts[j].y + ((pts[i].y<pts[j].y) ? -r : ((pts[i].y>pts[j].y) ? r : 0));
-
-            if ( sqrDistancePointLine(&p0, &p1, &p) <= fuzz*fuzz )
-                return YES;
-
-            if ( r )
-            {
-                c.x = pts[j].x + ((pts[j].x>pts[0].x) ? -radius : radius);
-                c.y = pts[j].y + ((pts[j].y>pts[0].y) ? -radius : radius);
-
-                if ( distancePointArc(p, c, r, begAngles[i], a) <= fuzz )
-                    return YES;
-            }
-        }
-
-/*
         p0 = origin;
         p1 = NSMakePoint(origin.x+size.x, origin.y);
         p2 = NSMakePoint(origin.x+size.x, origin.y+size.y);
         p3 = NSMakePoint(origin.x, origin.y+size.y);
-
-
         if ( sqrDistancePointLine(&p0, &p1, &p) <= fuzz*fuzz ||
              sqrDistancePointLine(&p1, &p2, &p) <= fuzz*fuzz ||
              sqrDistancePointLine(&p2, &p3, &p) <= fuzz*fuzz ||
              sqrDistancePointLine(&p3, &p0, &p) <= fuzz*fuzz )
             return YES;
-*/
     }
     return NO;
 }
 
-/* created: 1998-04-07
+/* created: 07.04.98
  */
 - (void)setDirectionCCW:(BOOL)ccw
 {
@@ -1164,8 +1061,6 @@
 
 /*
  * return a path representing the outline of us
- * modified: 2010-03-03 (setDirectionCCW:)
- *           2005-09-27
  */
 - contour:(float)w
 {
@@ -1176,15 +1071,12 @@
 
         [nr setWidth:0.0];
         [nr setColor:color];
-        [nr setRotAngle:rotAngle];
+        [nr setRotAngle:rotAngle];	
         [nr setFilled:NO];
         r = (w+width) / 2.0;	// the amount of growth
         o.x = origin.x - r;   o.y = origin.y - r;
         s.x = size.x + 2.0*r; s.y = size.y + 2.0*r;
-        if ( s.x < 0.0 || s.y < 0.0 )
-            return nil;
         o = vhfPointRotatedAroundCenter(o, rotAngle, origin);
-        [nr setDirectionCCW: isDirectionCCW];
         [nr setVertices:o :s];
         return nr;
     }
@@ -1369,13 +1261,13 @@
  * modified: 2004-02-28
  */
 - uniteWith:(id)ug
-{   int			i, j = 0, k, l, endIx=0, uStartIs[1000], startI, listCnt, uStartIsCnt = 0, uListCnt;
-    int			sPairsCnt = 0, ePairsCnt = 0, sPairsCnts[500], ePairsCnts[500];
-    int			removedFromUg = 0, removedFromNg = 0, sCnt=0, eCnt=0, startIs[1000], endIs[1000];
+{   int			i, j = 0, k, l, endIx=0, uStartIs[100], startI, listCnt, uStartIsCnt = 0, uListCnt;
+    int			sPairsCnt = 0, ePairsCnt = 0, sPairsCnts[50], ePairsCnts[50];
+    int			removedFromUg = 0, removedFromNg = 0, sCnt=0, eCnt=0, startIs[100], endIs[100];
     float		tol = (10.0*TOLERANCE);
     VPath		*ng;
     NSMutableArray	*splitListG, *splitListUg;
-    NSPoint		p, startPts[1000], endPts[1000];   // start/end point of removed graphic(s)
+    NSPoint		p, startPts[100], endPts[100];   // start/end point of removed graphic(s)
     BOOL		first = YES, removing = NO;
     NSAutoreleasePool	*pool;
 
@@ -1413,6 +1305,26 @@
             [splitListUg addObject:[[ug copy] autorelease]];
     }
 
+    /* ug is'nt a path and not splitted now there are two possibilities
+     * self is in ug or ug is in self else -> nothing to unite - NO
+     */
+    if ( ![ug isKindOfClass:[VPath class]] && [splitListUg count] == 1 && ![ug isKindOfClass:[VGroup class]])
+    {	NSPoint	p;
+
+        [pool release];
+        /* ug is inside self -> self is ok can remove ug later */
+        ( [ug isKindOfClass:[VPath class]] ) ? [[[(VPath*)ug list] objectAtIndex:0] getPoint:&p at:0.4] :
+            [ug getPoint:&p at:0.4];
+        if ( [self isPointInside:p] )
+            return [[self copy] autorelease];
+
+        /* self is inside ug -> ug is it */
+        [self getPoint:&p at:0.4];
+        if ( [(id)ug isPointInside:p] )
+            return [[ug copy] autorelease];
+        return NO;	/* nothing to unite */
+    }
+
     /* get startIndexes from splitListUg */
     uStartIsCnt = 1;
     uStartIs[0] = 0;
@@ -1422,26 +1334,18 @@
         VGraphic	*sg = [splitListUg objectAtIndex:uStartIs[uStartIsCnt-1]];
 
         endIx = -1;
-
         startPt = [sg pointWithNum:0];
         for ( i=uStartIs[uStartIsCnt-1]; i < uListCnt; i++ )
         {
             e = [[splitListUg objectAtIndex:i] pointWithNum:MAXINT];
             if ( SqrDistPoints(startPt, e) < tol*tol )
-            {
-                if (i+1 < uListCnt)
-                {   NSPoint	begN = [[splitListUg objectAtIndex:i+1] pointWithNum:0];
-
-                    if ( SqrDistPoints(e, begN) < (TOLERANCE*15)*(TOLERANCE*15) )
-                        continue; // dist to next gr is smaller !
-                }
-                endIx = i;
+            {   endIx = i;
                 break;
             }
         }
         if (endIx == -1)
         {   uStartIs[uStartIsCnt++] = uListCnt-1;
-            NSLog(@"VRectangle.m: -uniteWith: endIx not found !");
+            NSLog(@"VPath.m: -uniteWith: endIx not found !");
             break;
         }
         else
@@ -1501,9 +1405,9 @@
      */
     first = YES;
     removing = NO;
-    for ( i=startI, listCnt = [[ng list] count]; startI != -1 && (first || i != startI); i++ )
+    for ( i=startI, listCnt = [[ng list] count]; first || i != startI; i++ )
     {	id	gThis;
-        NSPoint	gPrevE = NSZeroPoint;
+        NSPoint	gPrevE;
         BOOL	currentlyRemoved = NO;
 
         i = (i >= listCnt) ? 0 : i;
@@ -1582,7 +1486,7 @@
                                 startIs[l] = startIs[l+2];
                             }
                             sCnt--; // we remove two points !
-//                            NSLog(@"VRectangle.m: -uniteWith: one startPt pair was currently removed");
+//                            NSLog(@"VPath.m: -uniteWith: one startPt pair was currently removed");
                         }
                         else if (spCnt > 1 && i == startIs[si0+1])
                         {
@@ -1621,8 +1525,8 @@
             listCnt--;
         }
         /* close gap with graphics from splitListUg */
-        if ((!currentlyRemoved && removing == YES) // i+1
-            || (removing == YES && !first && ((i+1 >= listCnt) ? (0) : (i+1)) == startI)) // last endpts to start gr
+        if ((!currentlyRemoved && removing == YES)
+            || (removing == YES && !first && i+1 == startI)) // than we must fill the gap also with/from ug
         {   NSPoint	s;
 
             /* search nextG for endPts[1]   no nextG found - startG == endG - only one Graphic ! */
@@ -1636,28 +1540,6 @@
             else // currentlyRemoved -> i perhaps -1
             {   int	l, nextI = ((i+1 >= listCnt) ? 0 : i+1);
 
-                /* correct endIs[eCnt-1] !!! - we remove the last graphic in list to startI */
-                if (i+1 >= listCnt) // endIs[eCnt-1]++ ! - nextI wird i+2 !
-                {
-                    /* we have to correct only the index !!! */
-                    for (l=nextI; l != ((i < 0) ? (listCnt-1) : i); l++)
-                    {   VGraphic	*gr = [[ng list] objectAtIndex:l];
-                        
-                    // if (k == i) break; // one time around
-                        s = [gr pointWithNum:0];
-                        if (SqrDistPoints(s, endPts[eCnt-1]) <= tol*tol) // nextG found
-                        {   //NSPoint	e = [gr pointWithNum:MAXINT];
-
-                            endIs[eCnt-1] = l;
-                            //endPts[eCnt-1] = e;
-                            break;
-                        }
-                        if (l == listCnt-1)
-                            l = -1; // go around until i !
-                    }
-                   //nextI = ((nextI+1 >= listCnt) ? 0 : nextI+1);
-                }
-
                 for (l=nextI; l != ((i < 0) ? (listCnt-1) : i); l++)
                 {   VGraphic	*gr = [[ng list] objectAtIndex:l];
                     
@@ -1699,17 +1581,6 @@
                 }
             }
         }
-        /* we must check if we remove a hole subpath */
-        for (i=0; i< uStartIsCnt-1; i++)
-        {
-            if (uStartIs[i] == uStartIs[i+1])
-            {
-                for (l=i; l < uStartIsCnt-1; l++)
-                    uStartIs[l] = uStartIs[l+1];
-                uStartIsCnt--;
-                i--; // perhaps we remove two or three
-            }
-        }
         if (![splitListUg count])
         {   [pool release];
             return ng;
@@ -1718,25 +1589,6 @@
 
     if (!removedFromNg && !removedFromUg)
     {
-        /* ug is'nt a path and not splitted now there are two possibilities
-        * self is in ug or ug is in self else -> nothing to unite - NO
-        */
-        if ( ![ug isKindOfClass:[VPath class]] && [splitListUg count] == 1 && ![ug isKindOfClass:[VGroup class]])
-        {	NSPoint	p;
-
-            [pool release];
-            /* ug is inside self -> self is ok can remove ug later */
-            ( [ug isKindOfClass:[VPath class]] ) ? [[[(VPath*)ug list] objectAtIndex:0] getPoint:&p at:0.4] :
-                [ug getPoint:&p at:0.4];
-            if ( [self isPointInside:p] )
-                return [[self copy] autorelease];
-
-            /* self is inside ug -> ug is it */
-            [self getPoint:&p at:0.4];
-            if ( [(id)ug isPointInside:p] )
-                return [[ug copy] autorelease];
-            return NO;	/* nothing to unite */
-        }
         [pool release];
         return NO;
     }
@@ -1746,7 +1598,7 @@
     for (i=0; i< sPairsCnt; i++)
     {   int	sptCnt = sPairsCnts[i], eptCnt = ePairsCnts[i], sIx = 1;
         int	sIs[2], eIs[2], sI0 = -1, eI0 = -1, endI = -1;
-        NSPoint	sPts[2], ePts[2] = {NSZeroPoint, NSZeroPoint};
+        NSPoint	sPts[2], ePts[2];
 
         /* count with i and sePairsCnts to the current startIs/startPts index */
         sI0 = 0;
@@ -1781,9 +1633,9 @@
                 for (k=0; k < sPairsCnt; k++)
                 {
                     if ((startIs[si] < listCnt &&
-                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
-                         // || (endIs[si] < listCnt &&
-                         // [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]])
+                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
+                        (endIs[si] < listCnt &&
+                         [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
                     {
                         [splitListUg removeObjectAtIndex:j];
                         /* korrect all uStartIs behind j */
@@ -1909,9 +1761,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
-                                    // || (endIs[si] < listCnt &&
-                                    // [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]])
+                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
+                                        (endIs[si] < listCnt &&
+                                         [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
                                     {
                                         gknIsDouble = YES;
                                         break;
@@ -1995,9 +1847,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
-                                    // || (endIs[si] < listCnt &&
-                                    // [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]])
+                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
+                                        (endIs[si] < listCnt &&
+                                         [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
                                     {
                                         gkpIsDouble = YES;
                                         break;
@@ -2019,8 +1871,7 @@
                     }
                 }
                 if (closeK != -1)
-                {   int		added = 0, from = closeK, to = j;
-                    float	dist = MAXCOORD;
+                {   int	added = 0, from = closeK, to = j;
 
                     /* get endI, eptCnt and eI0 */
                     if (pointWithToleranceInArray(closePt, tol, endPts, eCnt))
@@ -2032,7 +1883,7 @@
                             }
                     }
                     else
-                        NSLog(@"VRectangle.m: -uniteWith: this should be not possible");
+                        NSLog(@"VPath.m: -uniteWith: this should be not possible");
 
                     eI0 = 0;
                     for (k=0; k < ePairsCnt; k++)
@@ -2058,8 +1909,7 @@
                     /* if eCnt/sCnt > 1
                     * && ej/sj... gleich zu ..Pts[1] -> ..Is[0] aus [ng list] removen !!!!!!!!!! */
                     if (sptCnt > 1 &&
-                        (((dist=SqrDistPoints(ej, sPts[1])) < tol*tol && dist < SqrDistPoints(ej, sPts[0])) ||
-                         ((dist=SqrDistPoints(sj, sPts[1])) < tol*tol && dist < SqrDistPoints(sj, sPts[0]))) &&
+                        (SqrDistPoints(ej, sPts[1]) < tol*tol || SqrDistPoints(sj, sPts[1]) < tol*tol) &&
                         !pointWithToleranceInArray(sPts[1], tol, endPts, eCnt))
                     {   /* remove object at sIs[0] from [ng list] */
                         [[ng list] removeObjectAtIndex:sIs[0]];
@@ -2076,10 +1926,8 @@
                         listCnt--;
                     }
 
-                    if ((eptCnt > 1 &&
-                         ((dist=SqrDistPoints(closePt, ePts[1])) < tol*tol &&
-                          dist < SqrDistPoints(closePt, ePts[0]) && // tol*tol
-                          !pointWithToleranceInArray(ePts[1], tol, startPts, sCnt)))
+                    if ((eptCnt > 1 && (SqrDistPoints(closePt, ePts[1]) < tol*tol &&
+                                        !pointWithToleranceInArray(ePts[1], tol, startPts, sCnt)))
                         || (jumpOverOneEnd && eptCnt > 1 && SqrDistPoints(closePt, ePts[0]) < tol*tol))
                     {	int	ri = eIs[0];
 
@@ -2091,7 +1939,7 @@
                                 ri = -1; // nothing to remove
                             else
                             {   ri = -1;
-                                NSLog(@"VRectangle.m -uniteWith: not yet implemented");
+                                NSLog(@"VPAth.m -uniteWith: not yet implemented");
                             }
                         }
                         if (ri != -1)
@@ -2181,18 +2029,18 @@
     }
 
     /* add closed chapes from splitListUg to ng */
-    if (uStartIsCnt > 1 && [splitListUg count])
+    if (uStartIsCnt > 1)
     {
         for (i=0; i<uStartIsCnt-1; i++)
         {
-            if (uStartIs[i+1]-1 == uStartIs[i] && [splitListUg count] == 1) // only one object
+            if (uStartIs[i+1]-1 == uStartIs[i]) // only one object
             {   VGraphic	*g = [splitListUg objectAtIndex:uStartIs[i]];
 
                 if ([g isKindOfClass:[VArc class]] && Abs([(VArc*)g angle]) == 360.0)
                     [[ng list] addObject:[splitListUg objectAtIndex:j]];
                 continue;
             }
-            else if ([splitListUg count] >= uStartIs[i+1]-1)
+            else
             {   VGraphic	*gs = [splitListUg objectAtIndex:uStartIs[i]];
                 VGraphic	*ge = [splitListUg objectAtIndex:uStartIs[i+1]-1];
                 NSPoint		s, e;
@@ -2329,7 +2177,7 @@
         [plist setObject:propertyListFromFloat(graduateAngle) forKey:@"graduateAngle"];
     if (stepWidth != 7)
         [plist setObject:propertyListFromFloat(stepWidth) forKey:@"stepWidth"];
-    if (!(radialCenter.x == 0.5 && radialCenter.y == 0.5))
+    if (radialCenter.x != 0.5 && radialCenter.y != 0.5)
         [plist setObject:propertyListFromNSPoint(radialCenter) forKey:@"radialCenter"];
     return plist;
 }
@@ -2344,7 +2192,7 @@
     if (!filled && [plist objectForKey:@"filled"])
         filled = 1;
     if (!(fillColor = colorFromPropertyList([plist objectForKey:@"fillColor"], [self zone])))
-        [self setFillColor:[NSColor blackColor]/*[color copy]*/];
+        [self setFillColor:[color copy]];
     if (!(endColor = colorFromPropertyList([plist objectForKey:@"endColor"], [self zone])))
         [self setEndColor:[NSColor blackColor]];
     graduateAngle = [plist floatForKey:@"graduateAngle"];
