@@ -1,11 +1,11 @@
 /* VText.m
  * 2-D Text object
  *
- * Copyright (C) 1996-2003 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-02-15
- * modified: 2003-06-26
+ * modified: 2005-01-11
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -154,6 +154,7 @@ static void initClassVars()
     endColor = [[NSColor blackColor] retain];
     graduateAngle = 0.0;
     stepWidth = 7.0;
+    radialCenter = NSMakePoint(0.5, 0.5);
     //lineHeight = [[drawText font] pointSize];
     return [super init];
 }
@@ -201,6 +202,9 @@ static void initClassVars()
 - (void)setGraduateAngle:(float)a	{ graduateAngle = a; dirty = YES; }
 - (float)graduateAngle			{ return graduateAngle; }
 
+- (void)setRadialCenter:(NSPoint)rc	{ radialCenter = rc; dirty = YES; }
+- (NSPoint)radialCenter			{ return radialCenter; }
+
 - (void)setStepWidth:(float)sw	{ stepWidth = sw; dirty = YES; }
 - (float)stepWidth		{ return stepWidth; }
 
@@ -338,6 +342,17 @@ static void initClassVars()
     }
 }
 
+- (void)replaceCharactersInRange:(NSRange)range withString:(NSString*)string
+{
+    if (string)
+    {
+        [self makeMutableAttributedString];
+        [attributedString replaceCharactersInRange:range withString:string];
+        if ( [self fitHorizontal] )
+            [self kernToFitHorizontal];
+    }
+}
+
 - (void)makeMutableAttributedString
 {
     if ( ![attributedString isKindOfClass:[NSMutableAttributedString class]] )
@@ -1682,6 +1697,7 @@ static void initClassVars()
     [aCoder encodeObject:fillColor];
     [aCoder encodeObject:endColor];
     [aCoder encodeValuesOfObjCTypes:"ff", &graduateAngle, &stepWidth];
+    [aCoder encodeValuesOfObjCTypes:"{NSPoint=ff}", &radialCenter];
 }
 - (id)initWithCoder:(NSCoder *)aDecoder
 {   int	version;
@@ -1716,6 +1732,7 @@ static void initClassVars()
     {   fillColor = [[aDecoder decodeObject] retain];
         endColor = [[aDecoder decodeObject] retain];
         [aDecoder decodeValuesOfObjCTypes:"ff", &graduateAngle , &stepWidth];
+        [aDecoder decodeValuesOfObjCTypes:"{NSPoint=ff}", &radialCenter];
     }
     if ( version < 1 )
     {   float	f;
@@ -1740,10 +1757,17 @@ static void initClassVars()
     if (isSerialNumber) [plist setObject:@"YES" forKey:@"isSerialNumber"];
     if (fitHorizontal) [plist setObject:@"YES" forKey:@"fitHorizontal"];
     if (centerVertical) [plist setObject:@"YES" forKey:@"centerVertical"];
-    [plist setObject:propertyListFromNSColor(fillColor) forKey:@"fillColor"];
-    [plist setObject:propertyListFromNSColor(endColor) forKey:@"endColor"];
-    [plist setObject:propertyListFromFloat(graduateAngle) forKey:@"graduateAngle"];
-    [plist setObject:propertyListFromFloat(stepWidth) forKey:@"stepWidth"];
+
+    if (fillColor != [NSColor blackColor])
+        [plist setObject:propertyListFromNSColor(fillColor) forKey:@"fillColor"];
+    if (endColor != [NSColor blackColor])
+        [plist setObject:propertyListFromNSColor(endColor) forKey:@"endColor"];
+    if (graduateAngle)
+        [plist setObject:propertyListFromFloat(graduateAngle) forKey:@"graduateAngle"];
+    if (stepWidth != 7)
+        [plist setObject:propertyListFromFloat(stepWidth) forKey:@"stepWidth"];
+    if (radialCenter.x != 0.5 && radialCenter.y != 0.5)
+        [plist setObject:propertyListFromNSPoint(radialCenter) forKey:@"radialCenter"];
 
     return plist;
 }
@@ -1759,12 +1783,18 @@ static void initClassVars()
     fitHorizontal = ([plist objectForKey:@"fitHorizontal"] ? YES : NO);
     centerVertical = ([plist objectForKey:@"centerVertical"] ? YES : NO);
     [self font];
+
     if (!(fillColor = colorFromPropertyList([plist objectForKey:@"fillColor"], [self zone])))
         [self setFillColor:[color copy]];
     if (!(endColor = colorFromPropertyList([plist objectForKey:@"endColor"], [self zone])))
         [self setEndColor:[NSColor blackColor]];
     graduateAngle = [plist floatForKey:@"graduateAngle"];
-    stepWidth = [plist floatForKey:@"stepWidth"];
+    if ( !(stepWidth = [plist floatForKey:@"stepWidth"]))
+        stepWidth = 7.0;	// default;
+    if ([plist objectForKey:@"radialCenter"])
+        radialCenter = pointFromPropertyList([plist objectForKey:@"radialCenter"]);
+    else
+        radialCenter = NSMakePoint(0.5, 0.5);	// default
     return self;
 }
 
