@@ -1,14 +1,11 @@
 /* PSImport.m
  * PostScript import object
  *
- * Copyright (C) 1996-2011 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-25
- * modified: 2011-09-03 (-importPS: for GhostScript: try several string loadings to get encoding right)
- *           2009-02-02 (-importPS: for GhostScript: -dNOSAFER flag added
- *           2009-01-31 (-importPS: for GhostScript+DPS: remove Corel Draw garbage before %!PS-ADOBE...)
- *           2008-11-29 (init state.color in GhostScript version of importPS)
+ * modified: 2005-01-06
  *
  * This file is part of the vhf Import Library.
  *
@@ -39,7 +36,6 @@
 #include <ctype.h>
 #include <math.h>
 #include "PSImport.h"
-#include "../VHFShared/vhfCommonFunctions.h"
 #include "../VHFShared/vhf2DFunctions.h"
 #include "../VHFShared/types.h"
 #include "../VHFShared/VHFScannerAdditions.h"
@@ -104,14 +100,13 @@
 }
 
 /* created:   2002-01-29
- * modified:  2005-11-19
+ * modified:  2005-01-04
  * parameter: pdfData	the PDF data stream
  * purpose:   import pdf data
  */
 - importPDF:(NSData*)pdfData
 {   NSString	*app = [[NSProcessInfo processInfo] processName];
-    NSString	*pdfFile = vhfPathWithPathComponents(PS_TMPPATH,
-                           [app stringByAppendingString:@"_pdfImport.pdf"], nil);
+    NSString	*pdfFile = [NSString stringWithFormat:@"/tmp/%@_pdfImport.pdf", app];
     id		result;
 
     [pdfData writeToFile:pdfFile atomically:NO];
@@ -122,8 +117,7 @@
 }
 - importPDFFromFile:(NSString*)pdfFile
 {   NSString	*app = [[NSProcessInfo processInfo] processName], *commandLine;
-    NSString	*psFile = vhfPathWithPathComponents(PS_TMPPATH,
-                          [app stringByAppendingString:@"_pdfImport.eps"], nil);
+    NSString	*psFile = [NSString stringWithFormat:@"/tmp/%@_pdfImport.eps", app];
     NSData	*psData;
 
     /* convert pdf to eps */
@@ -157,8 +151,7 @@
     NSDPSContext	*curContext = [NSDPSContext currentContext];
     NSDPSServerContext	*psContext = nil;
     NSString		*app = [[NSProcessInfo processInfo] processName];
-    NSString		*path = vhfPathWithPathComponents(PS_TMPPATH,
-                                [app stringByAppendingString:@"_psImport"], nil);
+    NSString		*path = [NSString stringWithFormat:@"/tmp/%@_psImport", app];
     NSString		*data;
     NSUserDefaults	*userDefaults = [NSUserDefaults standardUserDefaults];
     NSString		*hostName = [userDefaults stringForKey:@"NSHost"];
@@ -167,28 +160,6 @@
 
     if ( !psData )
         return nil;
-    /* Workaround for Windows Corel Draw: if psData contains garbage before %!PS-Adobe, we remove that.
-     * garbage at the end is only removed if file ends with "%%EOF".
-     */
-    {   NSString    *psStr, *psStr1;
-        NSRange     range, range1;
-
-        psStr = [[NSString alloc] initWithData:psData encoding:NSASCIIStringEncoding];
-        if ( (range = [psStr rangeOfString:@"%!PS"]).length && range.location > 0 )  // garbage%!PS-Adobe
-        {   int toIx;
-
-            NSLog(@"PostScript-Import: Error in PostScript file - data starts with garbage (%@) !", [psStr substringToIndex:range.location]);
-            if ( ! (range1 = [psStr rangeOfString:@"%%EOF" options:NSBackwardsSearch]).length )
-                range1 = [psStr rangeOfString:@"showpage" options:NSBackwardsSearch];
-            toIx = ((range1.length) ? range1.location+range1.length+1 : [psStr length]);
-            psStr1 = [psStr substringWithRange:NSMakeRange(range.location, toIx-range.location)];
-            [psStr release];
-            psData = [psStr1 dataUsingEncoding:NSUTF8StringEncoding allowLossyConversion:YES];
-        }
-        else
-            [psStr release];
-    }
-
     state.color = [[NSColor colorWithCalibratedRed:0.0 green:0.0 blue:0.0 alpha:1.0] retain];
     state.width = 0.0;
 
@@ -237,38 +208,13 @@
 
 static NSString	*prolog = nil;
 - importPS:(NSData*)psData
-{   NSString            *app = [[NSProcessInfo processInfo] processName], *commandLine, *path;
-    NSString            *inFile = vhfPathWithPathComponents(PS_TMPPATH, [app stringByAppendingString:@"_psImport.in"], nil);
-    NSString            *outFile = vhfPathWithPathComponents(PS_TMPPATH, @"psImport.out", nil); // see psImport.prolog
-    NSMutableString     *data = [NSMutableString string];
-    NSStringEncoding    enc;
+{   NSString		*app = [[NSProcessInfo processInfo] processName], *commandLine, *path;
+    NSString		*inFile = [NSString stringWithFormat:@"/tmp/%@_psImport.in", app];
+    NSString		*outFile = [NSString stringWithFormat:@"/tmp/psImport.out"]; // see psImport.prolog
+    NSMutableString	*data = [NSMutableString string];
 
     if ( !psData )
         return nil;
-    /* Workaround for Windows Corel Draw: if psData contains garbage before %!PS-Adobe, we remove that.
-     * garbage at the end is only removed if file ends with "%%EOF".
-     */
-    {   NSString    *psStr, *psStr1;
-        NSRange     range, range1;
-
-        psStr = [[NSString alloc] initWithData:psData encoding:NSASCIIStringEncoding];
-        if ( (range = [psStr rangeOfString:@"%!PS"]).length && range.location > 0 )  // garbage%!PS-Adobe
-        {   int toIx;
-
-            NSLog(@"PostScript-Import: Error in PostScript file - data starts with garbage (%@) !", [psStr substringToIndex:range.location]);
-            if ( ! (range1 = [psStr rangeOfString:@"%%EOF" options:NSBackwardsSearch]).length )
-                range1 = [psStr rangeOfString:@"showpage" options:NSBackwardsSearch];
-            toIx = ((range1.length) ? range1.location+range1.length+1 : [psStr length]);
-            psStr1 = [psStr substringWithRange:NSMakeRange(range.location, toIx-range.location)];
-            [psStr release];
-            psData = [psStr1 dataUsingEncoding:NSUTF8StringEncoding allowLossyConversion:YES];
-        }
-        else
-            [psStr release];
-    }
-
-    state.color = [[NSColor colorWithCalibratedRed:0.0 green:0.0 blue:0.0 alpha:1.0] retain];
-    state.width = 0.0;
 
     /* load prolog from framework or library directory */
     if ( !prolog )
@@ -298,23 +244,17 @@ static NSString	*prolog = nil;
     }
     [data writeToFile:inFile atomically:NO];
 
-    commandLine = [NSString stringWithFormat:@"%@ -dNODISPLAY -dBATCH -dNOSAFER -g1000x1000 '%@'", [self gsPath], inFile];
+    commandLine = [NSString stringWithFormat:@"%@ -dNODISPLAY -dBATCH -g1000x1000 '%@'", [self gsPath], inFile];
     system([commandLine cString]);
 
     /* load generated file */
-    //data = [[[NSString alloc] initWithContentsOfFile:outFile] autorelease];
-    //if ( !data )
-    data = [[[NSString alloc] initWithContentsOfFile:outFile usedEncoding:&enc error:NULL] autorelease];
-    if ( !data )    // files from Corel Draw, etc.
-        data = [[[NSString alloc] initWithContentsOfFile:outFile encoding:NSISOLatin1StringEncoding error:NULL] autorelease];
-    if ( !data )    // files from Next-Step (ex. Example file with Ducks)
-        data = [[[NSString alloc] initWithContentsOfFile:outFile encoding:NSNEXTSTEPStringEncoding error:NULL] autorelease];
-    
+    data = [[[NSString alloc] initWithContentsOfFile:outFile] autorelease];
+
     /* interpret data and send to receiving object */
-    if ( !data || ![self interpret:data] )
+    if ( ![self interpret:data] )
         return nil;
 
-    [[NSFileManager defaultManager] removeFileAtPath:inFile  handler:nil];
+    [[NSFileManager defaultManager] removeFileAtPath:inFile handler:nil];
     [[NSFileManager defaultManager] removeFileAtPath:outFile handler:nil];
 
     return [list autorelease];
@@ -431,11 +371,8 @@ static NSString	*prolog = nil;
                 ok = NO; break;
             }
             //[state.color release];	// FIXME: this should be active but creates a crash ???
-            /*
-             * (k-c[cCnt-5]) instead (1.0-c[cCnt-5])*k
-             */
-            state.color = [[NSColor colorWithCalibratedRed:(k-c[cCnt-5]) green:(k-c[cCnt-4]) blue:(k-c[cCnt-3]) alpha:c[cCnt-1]] retain];
-            //state.color = [[NSColor colorWithCalibratedRed:(1.0-c[cCnt-5])*k green:(1.0-c[cCnt-4])*k blue:(1.0-c[cCnt-3])*k alpha:c[cCnt-1]] retain];
+            state.color = [[NSColor colorWithCalibratedRed:(1.0-c[cCnt-5])*k green:(1.0-c[cCnt-4])*k blue:(1.0-c[cCnt-3])*k alpha:c[cCnt-1]] retain];
+            //state.color = [NSColor colorWithDeviceCyan:c[cCnt-5] magenta:c[cCnt-4] yellow:c[cCnt-3] black:c[cCnt-2] alpha:c[cCnt-1]];
             cCnt = 0;
         }
         else if ( [scanner scanString:CURVE intoString:NULL] )		// curve
